@@ -1,9 +1,10 @@
 import argparse
-from argparse import Namespace
 import json
-from typing import Dict, Any
+from argparse import Namespace
+from typing import Any, Dict
 
 from mindee import Client
+from mindee.documents.base import serialize_for_json
 
 DOCUMENTS: Dict[str, Dict[str, Any]] = {
     "invoice": {
@@ -57,7 +58,7 @@ def _custom_client(args: Namespace):
     return client
 
 
-def call_endpoint(args):
+def call_endpoint(args: Namespace):
     """Call the endpoint given passed arguments."""
     if args.product_name == "custom":
         client = _custom_client(args)
@@ -71,14 +72,14 @@ def call_endpoint(args):
         with open(args.path, "rb", buffering=30) as file_handle:
             doc_to_parse = client.doc_from_file(file_handle, cut_pdf=args.cut_pdf)
     elif args.input_type == "base64":
-        with open(args.path, "rt") as file_handle:
+        with open(args.path, "rt", encoding="ascii") as base64_handle:
             doc_to_parse = client.doc_from_b64string(
-                file_handle.read(), "test.jpg", cut_pdf=args.cut_pdf
+                base64_handle.read(), "test.jpg", cut_pdf=args.cut_pdf
             )
     elif args.input_type == "bytes":
-        with open(args.path, "rb") as file_handle:
+        with open(args.path, "rb") as bytes_handle:
             doc_to_parse = client.doc_from_bytes(
-                file_handle.read(), file_handle.name, cut_pdf=args.cut_pdf
+                bytes_handle.read(), bytes_handle.name, cut_pdf=args.cut_pdf
             )
     else:
         doc_to_parse = client.doc_from_path(args.path, cut_pdf=args.cut_pdf)
@@ -91,13 +92,14 @@ def call_endpoint(args):
     if args.output_type == "raw":
         print(json.dumps(parsed_data.http_response, indent=2))
     elif args.output_type == "parsed":
-        print(json.dumps(getattr(parsed_data, doc_type), indent=2, default=vars))
+        doc = getattr(parsed_data, doc_type)
+        print(json.dumps(doc, indent=2, default=serialize_for_json))
     else:
         print(getattr(parsed_data, doc_type))
 
 
-def parse_args():
-    """Parse command line arguments"""
+def _parse_args() -> Namespace:
+    """Parse command line arguments."""
     parser = argparse.ArgumentParser(description="Mindee API")
     parser.add_argument(
         "-E",
@@ -116,7 +118,7 @@ def parse_args():
             subp.add_argument(
                 "-u",
                 "--user",
-                dest="account_name",
+                dest="username",
                 help="API account_name for the endpoint",
             )
             subp.add_argument(
@@ -184,5 +186,10 @@ def parse_args():
     return parsed_args
 
 
+def main() -> None:
+    """Run the Command Line Interface."""
+    call_endpoint(_parse_args())
+
+
 if __name__ == "__main__":
-    call_endpoint(parse_args())
+    main()
