@@ -3,7 +3,7 @@ from typing import List, Optional
 from mindee.documents.base import Document
 from mindee.documents.invoice import Invoice
 from mindee.documents.receipt import Receipt
-from mindee.fields import Field
+from mindee.fields.base import Field
 from mindee.fields.locale import Locale
 from mindee.fields.orientation import Orientation
 from mindee.http import Endpoint
@@ -26,7 +26,7 @@ class FinancialDocument(Document):
 
         :param api_prediction: Raw prediction from HTTP response
         :param input_file: Input object
-        :param page_n: Page number for multi pages pdf input
+        :param page_n: Page number for multi-page PDF input
         """
         self.total_incl = None
         self.total_excl = None
@@ -35,14 +35,14 @@ class FinancialDocument(Document):
         self.due_date = None
         self.taxes = []
         self.merchant_name = None
-        self.payment_details = None
-        self.company_number = None
+        self.payment_details = []
+        self.company_number = []
         self.vat_number = None
         self.total_tax = None
         self.time = None
         self.supplier_address = None
         self.customer_name = None
-        self.customer_company_registration = None
+        self.customer_company_registration = []
         self.customer_address = None
 
         # need this for building from prediction
@@ -95,13 +95,8 @@ class FinancialDocument(Document):
             self.time = receipt.time
             self.total_tax = receipt.total_tax
             self.invoice_number = Field({"value": None, "confidence": 0.0})
-            self.payment_details = []
-            self.company_number = []
             self.supplier_address = Field({"value": None, "confidence": 0.0})
             self.customer_name = Field({"value": None, "confidence": 0.0})
-            self.customer_company_registration = Field(
-                {"value": None, "confidence": 0.0}
-            )
             self.customer_address = Field({"value": None, "confidence": 0.0})
 
     def __str__(self) -> str:
@@ -135,20 +130,26 @@ class FinancialDocument(Document):
         )
 
     @staticmethod
-    def request(endpoints: List[Endpoint], input_file, include_words=False):
+    def request(
+        endpoints: List[Endpoint],
+        input_file,
+        include_words: bool = False,
+        close_file: bool = True,
+    ):
         """
         Make request to prediction endpoint.
 
         :param input_file: Input object
         :param endpoints: Endpoints config
         :param include_words: Include Mindee vision words in http_response
+        :param close_file: Whether to `close()` the file after parsing it.
         """
         if "pdf" in input_file.file_extension:
             # invoices is index 0, receipts 1 (this should be cleaned up)
             index = 0
         else:
             index = 1
-        return endpoints[index].predict_request(input_file, include_words)
+        return endpoints[index].predict_request(input_file, include_words, close_file)
 
     def _checklist(self) -> None:
         """Set the validation rules."""
