@@ -1,13 +1,12 @@
 from typing import List, Optional
 
 from mindee.documents.base import Document
-from mindee.fields import Field
 from mindee.fields.amount import Amount
+from mindee.fields.base import Field
 from mindee.fields.date import Date
 from mindee.fields.locale import Locale
 from mindee.fields.orientation import Orientation
 from mindee.fields.tax import Tax
-from mindee.http import Endpoint
 
 
 class Receipt(Document):
@@ -99,17 +98,6 @@ class Receipt(Document):
             {"value": None, "confidence": 0.0}, value_key="value", page_n=page_n
         )
 
-    @staticmethod
-    def request(endpoints: List[Endpoint], input_file, include_words=False):
-        """
-        Make request to prediction endpoint.
-
-        :param input_file: Input object
-        :param endpoints: Endpoints config
-        :param include_words: Include Mindee vision words in http_response
-        """
-        return endpoints[0].predict_request(input_file, include_words)
-
     def _checklist(self) -> None:
         """Call check methods."""
         self.checklist = {"taxes_match_total_incl": self.__taxes_match_total()}
