@@ -1,50 +1,31 @@
 import json
+
 import pytest
+
 from mindee.documents.financial_document import FinancialDocument
+from tests.documents.test_invoice import INVOICE_FILE_PATH, INVOICE_NA_FILE_PATH
+from tests.documents.test_receipt import RECEIPT_FILE_PATH, RECEIPT_NA_FILE_PATH
 
 
 @pytest.fixture
 def financial_doc_from_invoice_object():
-    invoice_json_repsonse = json.load(open("./tests/data/invoices/v2/invoice.json"))
+    invoice_json_repsonse = json.load(open(INVOICE_FILE_PATH))
     return FinancialDocument(
-        invoice_json_repsonse["document"]["inference"]["pages"][0]["prediction"]
+        invoice_json_repsonse["document"]["inference"]["prediction"], page_n=None
     )
 
 
 @pytest.fixture
 def financial_doc_from_receipt_object():
-    receipt_json_repsonse = json.load(
-        open("./tests/data/expense_receipts/v3/receipt.json")
-    )
+    receipt_json_repsonse = json.load(open(RECEIPT_FILE_PATH))
     return FinancialDocument(
-        receipt_json_repsonse["document"]["inference"]["pages"][0]["prediction"]
-    )
-
-
-@pytest.fixture
-def financial_doc_object_from_scratch():
-    return FinancialDocument(
-        locale="fr",
-        total_incl=12,
-        total_excl=15,
-        date="2018-12-21",
-        invoice_number="001",
-        due_date="2019-01-01",
-        taxes={(1, 10), (2, 20)},
-        merchant_name="Amazon",
-        payment_details="1231456498799765",
-        company_number="asdqsdae",
-        orientation=0,
-        total_tax=3,
-        time="12:15",
+        receipt_json_repsonse["document"]["inference"]["prediction"], page_n=None
     )
 
 
 @pytest.fixture
 def financial_doc_from_receipt_object_all_na():
-    json_repsonse = json.load(
-        open("./tests/data/expense_receipts/v3/receipt_all_na.json")
-    )
+    json_repsonse = json.load(open(RECEIPT_NA_FILE_PATH))
     return FinancialDocument(
         json_repsonse["document"]["inference"]["pages"][0]["prediction"]
     )
@@ -52,7 +33,7 @@ def financial_doc_from_receipt_object_all_na():
 
 @pytest.fixture
 def financial_doc_from_invoice_object_all_na():
-    json_repsonse = json.load(open("./tests/data/invoices/v2/invoice_all_na.json"))
+    json_repsonse = json.load(open(INVOICE_NA_FILE_PATH))
     return FinancialDocument(
         json_repsonse["document"]["inference"]["pages"][0]["prediction"]
     )
@@ -60,24 +41,29 @@ def financial_doc_from_invoice_object_all_na():
 
 @pytest.fixture
 def receipt_pred():
-    return json.load(open("./tests/data/expense_receipts/v3/receipt_all_na.json"))[
-        "document"
-    ]["inference"]["pages"][0]["prediction"]
+    return json.load(open(RECEIPT_NA_FILE_PATH))["document"]["inference"]["pages"][0][
+        "prediction"
+    ]
 
 
 @pytest.fixture
 def invoice_pred():
-    return json.load(open("./tests/data/invoices/v2/invoice_all_na.json"))["document"][
-        "inference"
-    ]["pages"][0]["prediction"]
+    return json.load(open(INVOICE_NA_FILE_PATH))["document"]["inference"]["pages"][0][
+        "prediction"
+    ]
 
 
 def test_constructor_1(financial_doc_from_invoice_object):
     assert financial_doc_from_invoice_object.date.value == "2020-02-17"
+    assert (
+        financial_doc_from_invoice_object.supplier_address.value
+        == "156 University Ave, Toronto ON, Canada M5H 2H7"
+    )
 
 
 def test_constructor_2(financial_doc_from_receipt_object):
     assert financial_doc_from_receipt_object.date.value == "2016-02-26"
+    assert financial_doc_from_receipt_object.supplier_address.value is None
 
 
 def test_all_na_receipt(financial_doc_from_receipt_object_all_na):
@@ -276,16 +262,16 @@ def test__shouldnt_raise_when_tax_rate_none(invoice_pred):
     assert financial_doc.checklist["taxes_match_total_incl"] is False
 
 
-def test_empty_object_works():
-    financial_doc = FinancialDocument()
-    assert financial_doc.total_tax.value is None
-
-
 def test_invoice_or_receipt_get_same_field_types(receipt_pred, invoice_pred):
     financial_doc_from_receipt = FinancialDocument(receipt_pred)
     financial_doc_from_invoice = FinancialDocument(invoice_pred)
     assert set(dir(financial_doc_from_invoice)) == set(dir(financial_doc_from_receipt))
     for key in dir(financial_doc_from_receipt):
-        assert type(getattr(financial_doc_from_receipt, key)) == type(
-            getattr(financial_doc_from_invoice, key)
-        )
+        if key.startswith("_"):
+            continue
+        receipt_attr = getattr(financial_doc_from_receipt, key)
+        invoice_attr = getattr(financial_doc_from_invoice, key)
+        print(key)
+        assert isinstance(
+            receipt_attr, type(invoice_attr)
+        ), f"Types do not match for: {key}"
