@@ -8,30 +8,36 @@ from mindee.inputs import Base64Document, BytesDocument, FileDocument, PathDocum
 def test_pdf_reconstruct_fail():
     with pytest.raises(AssertionError):
         PathDocument(
-            "./tests/data/invoices/invoice_6p.pdf",
+            "./tests/data/invoices/invoice_10p.pdf",
             cut_pdf=True,
             n_pdf_pages=4,
         )
 
 
 def test_pdf_reconstruct_ok():
-    input_file = PathDocument("./tests/data/invoices/invoice_6p.pdf")
+    input_file = PathDocument("./tests/data/invoices/invoice_10p.pdf")
     assert isinstance(input_file.file_object, io.BytesIO)
 
 
+def test_pdf_reconstruct_no_cut():
+    input_file = PathDocument("./tests/data/invoices/invoice_10p.pdf", cut_pdf=False)
+    assert input_file.count_pdf_pages() == 10
+    assert isinstance(input_file.file_object, io.BufferedReader)
+
+
 def test_pdf_reconstruct_check_n_pages():
     input_obj_3 = PathDocument(
-        "./tests/data/invoices/invoice_6p.pdf",
+        "./tests/data/invoices/invoice_10p.pdf",
         cut_pdf=True,
         n_pdf_pages=3,
     )
     input_obj_2 = PathDocument(
-        "./tests/data/invoices/invoice_6p.pdf",
+        "./tests/data/invoices/invoice_10p.pdf",
         cut_pdf=True,
         n_pdf_pages=2,
     )
     input_obj_1 = PathDocument(
-        "./tests/data/invoices/invoice_6p.pdf",
+        "./tests/data/invoices/invoice_10p.pdf",
         cut_pdf=True,
         n_pdf_pages=1,
     )
@@ -48,7 +54,7 @@ def test_pdf_reconstruct_check_n_pages():
 
 def test_input_from_path():
     input_obj_1 = PathDocument(
-        "./tests/data/invoices/invoice_6p.pdf",
+        "./tests/data/invoices/invoice_10p.pdf",
         cut_pdf=True,
         n_pdf_pages=1,
     )
@@ -56,16 +62,16 @@ def test_input_from_path():
 
 
 def test_input_from_file():
-    with open("./tests/data/invoices/invoice_6p.pdf", "rb") as fp:
+    with open("./tests/data/invoices/invoice_10p.pdf", "rb") as fp:
         input_obj_1 = FileDocument(fp, cut_pdf=True, n_pdf_pages=1)
     assert input_obj_1.count_pdf_pages() == 1
 
 
 def test_input_from_base64():
-    with open("./tests/data/invoices/invoice_6p.txt", "rt") as fp:
+    with open("./tests/data/invoices/invoice_10p.txt", "rt") as fp:
         input_obj_1 = Base64Document(
             fp.read(),
-            filename="invoice_6p.pdf",
+            filename="invoice_10p.pdf",
             cut_pdf=True,
             n_pdf_pages=1,
         )
@@ -73,10 +79,10 @@ def test_input_from_base64():
 
 
 def test_input_from_bytes():
-    with open("./tests/data/invoices/invoice_6p.pdf", "rb") as fp:
+    with open("./tests/data/invoices/invoice_10p.pdf", "rb") as fp:
         input_obj_1 = BytesDocument(
             fp.read(),
-            filename="invoice_6p.pdf",
+            filename="invoice_10p.pdf",
             cut_pdf=True,
             n_pdf_pages=1,
         )
@@ -84,10 +90,10 @@ def test_input_from_bytes():
 
 
 def test_pdf_blank_check():
-    with pytest.raises(Exception):
+    with pytest.raises(AssertionError):
         PathDocument("./tests/data/pdfs/blank.pdf")
 
-    with pytest.raises(Exception):
+    with pytest.raises(AssertionError):
         PathDocument("./tests/data/pdfs/blank_1.pdf")
 
     input_not_blank = PathDocument("./tests/data/pdfs/not_blank_image_only.pdf")
